@@ -2,6 +2,7 @@ package resource
 
 import (
 	"fmt"
+	"reflect"
 	"time"
 
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -14,6 +15,7 @@ import (
 
 	imageregistryv1 "github.com/openshift/cluster-image-registry-operator/pkg/apis/imageregistry/v1"
 	"github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/metrics"
 	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
 	"github.com/openshift/cluster-image-registry-operator/pkg/resource/object"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
@@ -99,9 +101,13 @@ func (g *Generator) syncStorage(cr *imageregistryv1.Config) error {
 	}
 
 	if runCreate {
+		reconf := g.storageReconfigured(cr, g.kubeconfig, g.listers)
 		if err := driver.CreateStorage(cr); err != nil {
 			return err
 		}
+		if reconf {
+			metrics.StorageReconfigured()
+		}
 	}
 
 	// XXX BZ 1722878
@@ -120,6 +126,29 @@ func (g *Generator) syncStorage(cr *imageregistryv1.Config) error {
 	return nil
 }
 
+// storageReconfigured returns true if we are, based on the provided config,
+// starting to use a different underlying storage location.
+func (g *Generator) storageReconfigured(
+	regCfg *imageregistryv1.Config,
+	restCfg *rest.Config,
+	listers *client.Listers,
+) bool {
+	prev, err := storage.NewDriver(&regCfg.Status.Storage, restCfg, listers)
+	if err != nil {
+		return false
+	}
+	cur, err := storage.NewDriver(&regCfg.Spec.Storage, restCfg, listers)
+	if err != nil {
+		return false
+	}
+
+	if reflect.TypeOf(prev) != reflect.TypeOf(cur) {
+		return true
+	}
+
+	return prev.ID() != cur.ID()
+}
+
 func (g *Generator) removeObsoleteRoutes(cr *imageregistryv1.Config) error {
 	routes, err := g.listers.Routes.List(labels.Everything())
 	if err != nil {
@@ -267,7 +296,13 @@ func (g *Generator) Remove(cr *imageregistryv1.Config) error {
 }
 
 func (g *Generator) ApplyClusterOperator(cr *imageregistryv1.Config) error {
-	gen := newGeneratorClusterOperator(g.listers.Deployments, g.listers.ClusterOperators, g.clients.Config, cr, nil)
+	gen := newGeneratorClusterOperator(
+		g.listers.Deployments,
+		g.listers.ClusterOperators,
+		g.clients.Config,
+		cr,
+		nil,
+	)
 
 	err := retry.RetryOnConflict(retry.DefaultBackoff, func() error {
 		o, err := gen.Get()
