@@ -32,6 +32,8 @@ const (
 
 	upiSecretName = "image-registry-private-configuration-user"
 	ipiSecretName = "installer-cloud-credentials"
+
+	cloudProviderConfigMapName = "cloud-provider-config"
 )
 
 var (
@@ -40,7 +42,8 @@ var (
 		"REGISTRY_STORAGE_SWIFT_USERNAME": []byte(username),
 		"REGISTRY_STORAGE_SWIFT_PASSWORD": []byte(password),
 	}
-	fakeCloudsYAML map[string][]byte
+	fakeCloudsYAML             map[string][]byte
+	fakeCloudProviderConfigMap map[string]string
 )
 
 type MockSecretNamespaceLister interface {
@@ -99,6 +102,32 @@ func (m MockIPISecretNamespaceLister) List(selector labels.Selector) ([]*corev1.
 	}, nil
 }
 
+type MockConfigMapNamespaceLister struct{}
+
+func (m MockConfigMapNamespaceLister) Get(name string) (*corev1.ConfigMap, error) {
+	if name == cloudProviderConfigMapName {
+		return &corev1.ConfigMap{
+			Data: fakeCloudProviderConfigMap,
+		}, nil
+	}
+
+	return nil, &k8serrors.StatusError{metav1.Status{
+		Status:  metav1.StatusFailure,
+		Code:    http.StatusNotFound,
+		Reason:  metav1.StatusReasonNotFound,
+		Details: &metav1.StatusDetails{},
+		Message: fmt.Sprintf("No config map with name %v was found", name),
+	}}
+}
+
+func (m MockConfigMapNamespaceLister) List(selector labels.Selector) ([]*corev1.ConfigMap, error) {
+	return []*corev1.ConfigMap{
+		{
+			Data: fakeCloudProviderConfigMap,
+		},
+	}, nil
+}
+
 func handleAuthentication(t *testing.T, endpointType string) {
 	th.Mux.HandleFunc("/v3/auth/tokens", func(w http.ResponseWriter, r *http.Request) {
 		th.TestMethod(t, r, "POST")
@@ -183,6 +212,7 @@ func mockConfig(includeStatus bool, endpoint string, secretLister MockSecretName
 		Listers: &regopclient.Listers{
 			Secrets:         secretLister,
 			Infrastructures: fakeInfrastructureLister(cloudName),
+			OpenShiftConfig: MockConfigMapNamespaceLister{},
 		},
 		Config: &config,
 	}
@@ -305,6 +335,7 @@ func TestSwiftSecrets(t *testing.T) {
 		Listers: &regopclient.Listers{
 			Secrets:         MockUPISecretNamespaceLister{},
 			Infrastructures: fakeInfrastructureLister(cloudName),
+			OpenShiftConfig: MockConfigMapNamespaceLister{},
 		},
 		Config: &config,
 	}
@@ -323,6 +354,7 @@ func TestSwiftSecrets(t *testing.T) {
 		Listers: &regopclient.Listers{
 			Secrets:         MockIPISecretNamespaceLister{},
 			Infrastructures: fakeInfrastructureLister(customCloud),
+			OpenShiftConfig: MockConfigMapNamespaceLister{},
 		},
 		Config: &config,
 	}
